Changelog
=========

2.3.0 (2019-02-04)
------------------

- Version bumped to 2.3.0

Added:

- Added new favicon for CRM. #74
  [netroxen]

- Note fields are now searchable using dexterityindexer.
  [netroxen]

Changed:

- Account items are now sorted on title instead of date.
  [netroxen]

- Batching does not limit results for Account items which are not published.
  [netroxen]

Bugfixes:

- Fixed language code in translation files.
  [netroxen]

- Plone toolbar icons for Content-Types now fixed.
  [netroxen]


2.2.1 (2018-04-16)
------------------

- Version bumped to 2.2.1

Changed:

- Bumped Plone to version 5.1.1.
  [netroxen]


2.2.0 (2018-04-16)
------------------

- Version bumped to 2.2.0

Changed:

- Bumped Plone to version 5.1.0.
  [netroxen]

- Cleaned up the buildout configuration.
  [netroxen]

Added:

- Added VCard support with an export option for contacts. #57
  [netroxen]

- Added page pagination to contacts and accounts views. #67
  [netroxen]


2.1.0 (2017-05-04)
------------------

- Version bumped to 2.1.0

Added:

- Added LDAP integration. #49
  [netroxen]


2.0.0 (2017-03-29)
------------------

- Initial 2.0.0 release.
  [netroxen]
